ResolvedBufferBinding

Type Alias ResolvedBufferBinding 

pub type ResolvedBufferBinding = BufferBinding<Arc<Buffer>>;

Aliased Type

#[repr(C)]
pub struct ResolvedBufferBinding { pub buffer: Arc<Buffer>, pub offset: u64, pub size: Option<u64>, }

Fields

buffer: Arc<Buffer>offset: u64size: Option<u64>

Size of the binding. If None, the binding spans from offset to the end of the buffer.

We use BufferAddress to allow a size of zero on this wgpu_core type, because JavaScript bindings cannot readily express Option<NonZeroU64>. The wgpu API uses Option<BufferSize> (i.e. NonZeroU64) for this field.